summaryrefslogtreecommitdiff
path: root/src/region-cache.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2013-03-08 13:37:41 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2013-03-08 13:37:41 -0800
commit457882c20c301f076ff6a4ef7ffd78ed3d35e699 (patch)
treef5295ec9fd8cdf57a90b99a52be684cf71b4361b /src/region-cache.c
parentb5426561089d39f18b42bed9dbfcb531f43ed562 (diff)
downloademacs-457882c20c301f076ff6a4ef7ffd78ed3d35e699.tar.gz
region-cache.c, scroll.c, search.c: Use bool for booleans.
* lisp.h (compile_pattern): * scroll.c (do_scrolling, do_direct_scrolling): * search.c (struct regexp_cache, compile_pattern_1) (compile_pattern, string_match_1, search_command) (trivial_regexp_p, search_buffer, Freplace_match, match_limit) (search_regs_saved, Fregexp_quote): Use bool for boolean. * region-cache.c (region_cache_forward, region_cache_backward): Fix comments to match code: these functions return int, not boolean.
Diffstat (limited to 'src/region-cache.c')
-rw-r--r--src/region-cache.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/region-cache.c b/src/region-cache.c
index 14e6982cd9a..452a5b3a065 100644
--- a/src/region-cache.c
+++ b/src/region-cache.c
@@ -695,8 +695,9 @@ know_region_cache (struct buffer *buf, struct region_cache *c,
/* Interface: using the cache. */
-/* Return true if the text immediately after POS in BUF is known, for
- the purposes of CACHE. If NEXT is non-zero, set *NEXT to the nearest
+/* Return the value for the text immediately after POS in BUF if the value
+ is known, for the purposes of CACHE, and return zero otherwise.
+ If NEXT is non-zero, set *NEXT to the nearest
position after POS where the knowledge changes. */
int
region_cache_forward (struct buffer *buf, struct region_cache *c,
@@ -732,8 +733,9 @@ region_cache_forward (struct buffer *buf, struct region_cache *c,
}
}
-/* Return true if the text immediately before POS in BUF is known, for
- the purposes of CACHE. If NEXT is non-zero, set *NEXT to the nearest
+/* Return the value for the text immediately before POS in BUF if the
+ value is known, for the purposes of CACHE, and return zero
+ otherwise. If NEXT is non-zero, set *NEXT to the nearest
position before POS where the knowledge changes. */
int region_cache_backward (struct buffer *buf, struct region_cache *c,
ptrdiff_t pos, ptrdiff_t *next)